package sun.awt.motif;

import java.awt.Dimension;

class PSPaperSize {
   String paperSizeName;
   Dimension paperSize;
   int tolerance;
   static final PSPaperSize[] standardSizeTable = new PSPaperSize[]{new PSPaperSize("A3", 842, 1191), new PSPaperSize("A4", 595, 842), new PSPaperSize("B4", 729, 1032), new PSPaperSize("ISOB4", 709, 1001), new PSPaperSize("Legal13", 612, 936), new PSPaperSize("Letter", 612, 792), new PSPaperSize("Legal", 612, 1008), new PSPaperSize("Tabloid", 792, 1224), new PSPaperSize("A4Small", 595, 842), new PSPaperSize("LetterSmall", 612, 792), new PSPaperSize("Executive", 36, 540, 720)};

   public String name() {
      return this.paperSizeName;
   }

   public Dimension size() {
      return this.paperSize;
   }

   public int width() {
      return this.paperSize.width;
   }

   public int height() {
      return this.paperSize.height;
   }

   public String toPostScriptCode(int var1, boolean var2) {
      if (var1 == 2) {
         return "mark {\n%%BeginFeature: ManualFeed " + var2 + "\n" + "<</ManualFeed " + var2 + ">> setpagedevice\n" + "%%EndFeature\n" + "%%BeginFeature: PageSize *" + this.paperSizeName + "\n" + "<< /PageSize [" + this.width() + " " + this.height() + "]\n" + "   /ImagingBBox null\n" + "   /Policies <</PageSize 3>>\n" + " >> setpagedevice\n" + "%%EndFeature\n" + "} stopped cleartomark";
      } else {
         String var3 = this.paperSizeName.toLowerCase();
         if (!var2) {
            var3 = var3 + "tray";
         }

         return "mark {\n%%BeginFeature: ManualFeed " + var2 + "\n" + "1 dict dup /ManualFeed " + var2 + " put setpagedevice\n" + "%%EndFeature\n" + "} stopped {\n" + "%%BeginFeature: *ManualFeed " + var2 + "\n" + "  statusdict /manualfeed " + var2 + " put\n" + "%%EndFeature\n" + "} if cleartomark mark {\n" + "%%BeginFeature: PageSize *" + this.paperSizeName + "\n" + "3 dict begin\n" + "   /PageSize [" + this.width() + " " + this.height() + "] def\n" + "   /ImagingBBox null def\n" + "   /Policies 1 dict dup/PageSize 3 put def\n" + " currentdict end setpagedevice\n" + "%%EndFeature\n" + "} stopped {\n" + "  cleartomark statusdict begin mark {\n" + "%%BeginFeature: *PageSize " + this.paperSizeName + "\n" + "  " + var3 + "\n" + "%%EndFeature\n" + "  } stopped end\n" + "} if cleartomark\n" + "% now make sure we got what we requested!\n" + "gsave initgraphics clippath pathbbox grestore\n" + "5 dict begin\n" + "  3 -1 roll /yoff exch def 3 -1 roll /xoff exch def\n" + "  yoff sub /h exch def xoff sub /w exch def\n" + "  w " + (this.paperSize.width - 36) + " lt h " + (this.paperSize.height - 36) + " lt or {\n" + "    w 2 div xoff add h 2 div yoff add translate\n" + "    w xoff 2 mul add " + this.paperSize.width + " div\n" + "    h yoff 2 mul add " + this.paperSize.height + " div\n" + "    2 copy gt {exch} if pop dup scale\n" + "    " + -this.paperSize.width / 2 + " " + -this.paperSize.height / 2 + " translate\n" + "  } if\n" + "end\n";
      }
   }

   public String toPostScriptCode() {
      return this.toPostScriptCode(1, false);
   }

   public String toString() {
      return "PSPaperSize[" + this.paperSizeName + ": " + this.paperSize.width + "x" + this.paperSize.height + "]";
   }

   public PSPaperSize(String var1, int var2, int var3) {
      this.paperSizeName = var1;
      this.tolerance = 0;
      this.paperSize = new Dimension(var2, var3);
   }

   public PSPaperSize(String var1, int var2, int var3, int var4) {
      this.paperSizeName = var1;
      this.tolerance = var2;
      this.paperSize = new Dimension(var3, var4);
   }

   public static PSPaperSize find(String var0) {
      if (var0 == null) {
         return null;
      } else {
         for(int var1 = 0; var1 < standardSizeTable.length; ++var1) {
            if (var0.equalsIgnoreCase(standardSizeTable[var1].paperSizeName)) {
               return standardSizeTable[var1];
            }
         }

         return null;
      }
   }

   public static PSPaperSize find(int var0, int var1, int var2) {
      int var3 = var2 + 1;
      int var4 = var2 + 1;
      PSPaperSize var5 = null;

      for(int var6 = 0; var6 < standardSizeTable.length; ++var6) {
         PSPaperSize var7 = standardSizeTable[var6];
         int var8 = Math.abs(var7.paperSize.width - var0);
         int var9 = Math.abs(var7.paperSize.height - var1);
         if (var8 <= var7.tolerance && var9 <= var7.tolerance) {
            return var7;
         }

         if (var8 <= var2 && var9 <= var2 && var8 + var9 < var3 + var4) {
            var3 = var8;
            var4 = var9;
            var5 = var7;
         }
      }

      return var5;
   }

   public static PSPaperSize find(int var0, int var1) {
      return find(var0, var1, 0);
   }
}
